# Generated by Django 3.0 on 2019-12-18 10:32

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('CustomAuth', '0004_auto_20191217_0409'),
    ]

    operations = [
        migrations.RenameField(
            model_name='user',
            old_name='permissions',
            new_name='user_permissions',
        ),
    ]
