from .anonymous import anonymous_required
from .group import group_required
from .superuser import superuser_only
from .ajax import ajax_required
from .timer import timeit
from .jwt import jwt as jwt_required

# TODO : Convert to class based decorator
