<!DOCTYPE html>
{% load render_table from django_tables2 %}
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>List of User</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css" />
</head>
<body>
    {% render_table table %}
</body>
</html>