# Generated by Django 3.0 on 2019-12-17 00:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('CustomAuth', '0003_user_wallet'),
    ]

    operations = [
        migrations.RenameField(
            model_name='user',
            old_name='is_register',
            new_name='is_verify',
        ),
        migrations.AlterField(
            model_name='user',
            name='last_name',
            field=models.CharField(blank=True, max_length=200, null=True, verbose_name='last name'),
        ),
    ]
