from .verify_email_token_generator import VerifyEmailTokenGenerator
from .magic_token_generator import MagicTokenGenerator

account_verify_email_token = VerifyEmailTokenGenerator()
magic_token = MagicTokenGenerator()
