{% load static %}

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{{title}}</title>

    <link href="//maxcdn.bootstrapcdn.com/bootstrap/4.1.1/css/bootstrap.min.css" rel="stylesheet" id="bootstrap-css">
    <link href="{% static 'CustomAuth/assets/css/status.css' %}" rel="stylesheet">

</head>
<body>

<section class="error_section">
    <p class="error_section_subtitle">{{ text }}</p>
    <h1 class="error_title">
        <p>{{code}}</p>
        {{code}}
    </h1>
</section>

<script src="//maxcdn.bootstrapcdn.com/bootstrap/4.1.1/js/bootstrap.min.js"></script>
<script src="//cdnjs.cloudflare.com/ajax/libs/jquery/3.2.1/jquery.min.js"></script>
<script src="{% static 'CustomAuth/assets/js/status.js' %}"></script>

</body>

</html>